@@ -1,4 +1,4 @@
 inline bool BigInt::isOne() const
 {
-    return BN_is_one(&d_bn);
+    return BN_is_one(d_bn);
 }
